@@ -53,12 +53,10 @@ class RSession : public Cantor::Session
     void runFirstExpression() override;
 
     void sendInputToServer(const QString& input);
-    void updateSymbols();
   protected Q_SLOTS:
     void serverChangedStatus(int status);
-
-  Q_SIGNALS:
-    void symbolsChanged();
+    void expressionFinished(int returnCode, const QString& text, const QStringList& files);
+    void inputRequested(QString info);
 
   private:
     QProcess* m_process;
