@@ -32,13 +32,23 @@ class RVariableModel : public Cantor::DefaultVariableModel
     RVariableModel( RSession* session);
     ~RVariableModel() override;
 
+    // List of virables from other R namespaces (packages), which can be treted as constants, like "pi"
+    //QStringList constants() const;
+
     void update() override;
 
+  Q_SIGNALS:
+    void constantsAdded(QStringList);
+    void constantsRemoved(QStringList);
+
   public Q_SLOTS:
     void parseResult(Cantor::Expression::Status status);
 
   private:
-    QStringList m_functions;
+    void setConstants(QStringList constants);
+
+  private:
+    QStringList m_constants;
     Cantor::Expression* m_expression;
 };
 
