@@ -24,10 +24,13 @@
 #include "expression.h"
 #include "result.h"
 #include "textresult.h"
+#include "helpresult.h"
 #include "imageresult.h"
 #include "defaultvariablemodel.h"
 #include "completionobject.h"
 
+#include "settings.h"
+
 QString TestJulia::backendName()
 {
     return QLatin1String("julia");
@@ -58,8 +61,7 @@ void TestJulia::testException()
     Cantor::Expression *e = evalExp(QLatin1String("sqrt(-1)"));
     QVERIFY(e != nullptr);
     QCOMPARE(e->status(), Cantor::Expression::Error);
-    QVERIFY(e->result());
-    QVERIFY(e->result()->type() == Cantor::TextResult::Type);
+    QCOMPARE(e->results().size(), 0);
     QVERIFY(
         !e->errorMessage().isEmpty()
         && e->errorMessage().contains(QLatin1String(
@@ -74,7 +76,7 @@ void TestJulia::testSyntaxError()
     Cantor::Expression *e = evalExp(QLatin1String("for i = 1:10\nprint(i)"));
     QVERIFY(e != nullptr);
     QCOMPARE(e->status(), Cantor::Expression::Error);
-    QVERIFY(e->result()->type() == Cantor::TextResult::Type);
+    QCOMPARE(e->results().size(), 0);
     QVERIFY(
         !e->errorMessage().isEmpty()
         && e->errorMessage().contains(QLatin1String(
@@ -124,6 +126,13 @@ void TestJulia::testPartialResultOnException()
 
 void TestJulia::testInlinePlot()
 {
+    if (!JuliaSettings::integratePlots())
+        QSKIP("This test needs enabled plots integration in Julia settings", SkipSingle);
+
+    Cantor::Expression* testGR = evalExp(QLatin1String("import GR"));
+    if (testGR->status() == Cantor::Expression::Error)
+        QSKIP("GR module not found, so skip tests for graphic", SkipSingle);
+
     Cantor::Expression *e = evalExp(QLatin1String(
         "import GR\n"
         "GR.plot([-1, -0.75, -0.5, -0.25, 0, 0.25, 0.5, 0.75, 1], sin)"
@@ -135,6 +144,13 @@ void TestJulia::testInlinePlot()
 
 void TestJulia::testInlinePlotWithExceptionAndPartialResult()
 {
+    if (!JuliaSettings::integratePlots())
+        QSKIP("This test needs enabled plots integration in Julia settings", SkipSingle);
+
+    Cantor::Expression* testGR = evalExp(QLatin1String("import GR"));
+    if (testGR->status() == Cantor::Expression::Error)
+        QSKIP("GR module not found, so skip tests for graphic", SkipSingle);
+
     Cantor::Expression *e = evalExp(QLatin1String(
         "import GR\n"
         "print(\"gonna plot\")\n"
@@ -143,6 +159,7 @@ void TestJulia::testInlinePlotWithExceptionAndPartialResult()
     ));
     QVERIFY(e != nullptr);
     QCOMPARE(e->status(), Cantor::Expression::Error);
+    QVERIFY(e->result());
     QVERIFY(e->result()->type() == Cantor::TextResult::Type);
     QCOMPARE(e->result()->data().toString(), QLatin1String("gonna plot"));
     QVERIFY(
@@ -306,5 +323,47 @@ void TestJulia::testExpressionQueue()
     QCOMPARE(cleanOutput(e3->result()->data().toString()), QLatin1String("3"));
 }
 
+void TestJulia::testHelpRequest()
+{
+    QSKIP("Skip, until we add this functionality to Julia backend", SkipSingle);
+    Cantor::Expression* e = evalExp(QLatin1String("?print"));
+
+    QVERIFY(e != nullptr);
+    QCOMPARE(e->status(), Cantor::Expression::Status::Done);
+    QVERIFY(e->result() != nullptr);
+    QCOMPARE(e->result()->type(), (int)Cantor::HelpResult::Type);
+    QString text = QString::fromLatin1("Write to io (or to the default output stream stdout").toHtmlEscaped();
+    text.replace(QLatin1Char(' '), QLatin1String("&nbsp;"));
+    QVERIFY(e->result()->toHtml().contains(text));
+}
+
+void TestJulia::testLoginLogout()
+{
+    // Logout from session twice and all must works fine
+    session()->logout();
+    session()->logout();
+
+    // Login in session twice and all must works fine
+    session()->login();
+    session()->login();
+}
+
+void TestJulia::testRestartWhileRunning()
+{
+    Cantor::Expression* e1=session()->evaluateExpression(QLatin1String("sleep(5)"));
+
+    session()->logout();
+    QCOMPARE(session()->status(), Cantor::Session::Disable);
+    QCOMPARE(e1->status(), Cantor::Expression::Interrupted);
+    session()->login();
+
+    Cantor::Expression* e2=evalExp( QLatin1String("2+2") );
+
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e2->result() != nullptr);
+
+    QCOMPARE(cleanOutput(e2->result()->data().toString() ), QLatin1String("4"));
+}
+
 QTEST_MAIN(TestJulia)
 
