@@ -31,9 +31,4 @@ QString     luahelper_dostring   (lua_State* L, const QString& str);
 QString     luahelper_getprinted (lua_State* L);
 QStringList luahelper_completion (lua_State* L, const QString& name);
 
-/* compile-time */
-QStringList luahelper_keywords   ();
-QStringList luahelper_functions  ();
-QStringList luahelper_variables  ();
-
 #endif /* _LUAHELPER_H */
