@@ -26,8 +26,8 @@
 class LuaHighlighter : public Cantor::DefaultHighlighter
 {
 public:
-    LuaHighlighter(QObject* parent);
-    ~LuaHighlighter();
+    explicit LuaHighlighter(QObject* parent);
+    ~LuaHighlighter() override = default;
 };
 
 #endif // LUAHIGHLIGHTER_H
