@@ -99,7 +99,7 @@ KConfigSkeleton* PythonBackend::config() const
 
 bool PythonBackend::requirementsFullfilled(QString* const reason) const
 {
-    const QString& path = PythonSettings::pythonServerPath().toLocalFile();
+    const QString& path = QStandardPaths::findExecutable(QLatin1String("cantor_pythonserver"));
     return Cantor::Backend::checkExecutable(QLatin1String("Cantor Python Server"), path, reason);
 }
 
