@@ -21,6 +21,8 @@
 #ifndef _PYTHONHIGHLIGHTER_H
 #define _PYTHONHIGHLIGHTER_H
 
+#include <QRegularExpression>
+
 #include "defaulthighlighter.h"
 class PythonSession;
 
@@ -29,15 +31,15 @@ class PythonHighlighter : public Cantor::DefaultHighlighter
     Q_OBJECT
 
   public:
-    explicit PythonHighlighter(QObject* parent, PythonSession* session, const int pythonVersion);
+    explicit PythonHighlighter(QObject* parent, PythonSession* session);
     ~PythonHighlighter() override = default;
 
   protected:
     void highlightBlock(const QString& text) override;
 
   private:
-     QRegExp commentStartExpression;
-     QRegExp commentEndExpression;
+     QRegularExpression commentStartExpression;
+     QRegularExpression commentEndExpression;
 };
 
 #endif /* _PYTHONHIGHLIGHTER_H */
