@@ -22,12 +22,18 @@
 #define _PYTHONUTILS_H
 
 #include <QFile>
+#include <QDebug>
 
 inline QString fromSource(const QString& resourceName)
 {
     QFile text(resourceName);
-    text.open(QIODevice::ReadOnly);
-    return QString::fromLatin1(text.readAll());
+    if (text.open(QIODevice::ReadOnly))
+        return QString::fromUtf8(text.readAll());
+    else
+    {
+        qWarning() << "Cantor Python resource" << resourceName << "didn't open - something wrong";
+        return QString();
+    }
 }
 
 #endif
