@@ -119,6 +119,33 @@ void TestSage::testNoOutput()
     QCOMPARE( e->result()->data().toString(), QLatin1String("2") );
 }
 
+void TestSage::testLoginLogout()
+{
+    // Logout from session twice and all must works fine
+    session()->logout();
+    session()->logout();
+
+    // Login in session twice and all must works fine
+    session()->login();
+    session()->login();
+}
+
+void TestSage::testRestartWhileRunning()
+{
+    Cantor::Expression* e1=session()->evaluateExpression(QLatin1String("import time; time.sleep(5)"));
+
+    session()->logout();
+    QCOMPARE(e1->status(), Cantor::Expression::Interrupted);
+    session()->login();
+
+    Cantor::Expression* e2=evalExp( QLatin1String("2+2") );
+
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e2->result() != nullptr);
+
+    QCOMPARE(e2->result()->data().toString(), QLatin1String("4"));
+}
+
 
 QTEST_MAIN( TestSage )
 
