@@ -19,6 +19,8 @@
  */
 #include "cantor.h"
 
+#include <cassert>
+
 #include <KActionCollection>
 #include <KConfigDialog>
 #include <KConfigGroup>
@@ -47,9 +49,11 @@
 
 #include "settings.h"
 #include "ui_settings.h"
+#include "ui_formating.h"
 #include "backendchoosedialog.h"
+#include <QMetaObject>
 
-CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr)
+CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr), m_panelHandler(nullptr)
 {
     // set the shell's ui resource file
     setXMLFile(QLatin1String("cantor_shell.rc"));
@@ -75,6 +79,8 @@ CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr)
 
     setDockOptions(QMainWindow::AnimatedDocks|QMainWindow::AllowTabbedDocks|QMainWindow::VerticalTabs);
 
+    initPanels();
+
     updateNewSubmenu();
 }
 
@@ -95,15 +101,32 @@ CantorShell::~CantorShell()
     m_panels.clear();
 }
 
-void CantorShell::load(const QUrl &url)
+void CantorShell::load(const QUrl& url)
 {
-    if (!m_part||!m_part->url().isEmpty() || m_part->isModified() )
+    // If the url already opened, then don't open the url in another tab, but
+    // just activate the already existed tab
+    for (int i = 0; i < m_parts.size(); i++)
+    {
+        auto* part = m_parts[i];
+        if (part && part->url() == url)
+        {
+            if (m_tabWidget->currentIndex() != i)
+                activateWorksheet(i);
+            else
+                KMessageBox::information(this, i18n("The file %1 is already opened.", QFileInfo(url.toLocalFile()).fileName()), i18n("Open file"));
+            return;
+        }
+    }
+
+    if (!m_part || !m_part->url().isEmpty() || m_part->isModified())
     {
         addWorksheet(QString());
-        m_tabWidget->setCurrentIndex(m_parts.size()-1);
+        m_tabWidget->setCurrentIndex(m_parts.size() - 1);
     }
-    if (!m_part->openUrl( url ))
+
+    if (!m_part->openUrl(url))
         closeTab(m_tabWidget->currentIndex());
+
     if (m_recentProjectsAction)
         m_recentProjectsAction->addUrl(url);
 
@@ -120,7 +143,7 @@ void CantorShell::setupActions()
     m_recentProjectsAction->setPriority(QAction::LowPriority);
     m_recentProjectsAction->loadEntries(KSharedConfig::openConfig()->group(QLatin1String("Recent Files")));
 
-    KStandardAction::close (this,  SLOT(closeTab()),  actionCollection());
+    KStandardAction::close(this, SLOT(closeTab()),  actionCollection());
 
     KStandardAction::quit(qApp, SLOT(closeAllWindows()), actionCollection());
 
@@ -132,15 +155,15 @@ void CantorShell::setupActions()
 
     KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 
-    QAction * downloadExamples = new QAction(i18n("Download Example Worksheets"), actionCollection());
+    QAction* downloadExamples = new QAction(i18n("Download Example Worksheets"), actionCollection());
     downloadExamples->setIcon(QIcon::fromTheme(QLatin1String("get-hot-new-stuff")));
     actionCollection()->addAction(QLatin1String("file_example_download"),  downloadExamples);
-    connect(downloadExamples, SIGNAL(triggered()), this,  SLOT(downloadExamples()));
+    connect(downloadExamples, &QAction::triggered, this,  &CantorShell::downloadExamples);
 
-    QAction * openExample =new QAction(i18n("&Open Example"), actionCollection());
+    QAction* openExample = new QAction(i18n("&Open Example"), actionCollection());
     openExample->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
     actionCollection()->addAction(QLatin1String("file_example_open"), openExample);
-    connect(openExample, SIGNAL(triggered()), this, SLOT(openExample()));
+    connect(openExample, &QAction::triggered, this, &CantorShell::openExample);
 
     QAction* toPreviousTab = new QAction(i18n("Go to previous worksheet"), actionCollection());
     actionCollection()->addAction(QLatin1String("go_to_previous_tab"), toPreviousTab);
@@ -216,7 +239,7 @@ void CantorShell::fileOpen()
     // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
     // button is clicked
     static const QString& filter = i18n("All supported files (*.cws *ipynb);;Cantor Worksheet (*.cws);;Jupyter Notebook (*.ipynb)");
-    QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Open file"), QUrl(), filter, &m_previousFilter);
+    const QUrl& url = QFileDialog::getOpenFileUrl(this, i18n("Open file"), QUrl(), filter, &m_previousFilter);
 
     if (url.isEmpty() == false)
     {
@@ -235,7 +258,7 @@ void CantorShell::fileOpen()
             newWin->load( url );
             newWin->show();
             }*/
-        load( url );
+        load(url);
     }
 }
 
@@ -272,14 +295,14 @@ void CantorShell::addWorksheet()
 
     }else
     {
-        QTextBrowser *browser=new QTextBrowser(this);
-        QString backendList=QLatin1String("<ul>");
+        QTextBrowser* browser = new QTextBrowser(this);
+        QString backendList = QLatin1String("<ul>");
         int backendListSize = 0;
-        foreach(Cantor::Backend* b, Cantor::Backend::availableBackends())
+        for (auto* backend : Cantor::Backend::availableBackends())
         {
-            if(!b->requirementsFullfilled()) //It's disabled because of missing dependencies, not because of some other reason(like eg. nullbackend)
+            if(!backend->requirementsFullfilled()) //It's disabled because of missing dependencies, not because of some other reason(like eg. nullbackend)
             {
-                backendList+=QString::fromLatin1("<li>%1: <a href=\"%2\">%2</a></li>").arg(b->name(), b->url());
+                backendList += QString::fromLatin1("<li>%1: <a href=\"%2\">%2</a></li>").arg(backend->name(), backend->url());
                 ++backendListSize;
             }
         }
@@ -338,19 +361,24 @@ void CantorShell::addWorksheet(const QString& backendName)
         }
 
         // now that the Part is loaded, we cast it to a Part to get our hands on it
-        KParts::ReadWritePart* part = factory->create<KParts::ReadWritePart>(m_tabWidget, QVariantList()<<backendName);
+        auto* part = factory->create<KParts::ReadWritePart>(m_tabWidget, QVariantList()<<backendName);
         if (part)
         {
             connect(part, SIGNAL(setCaption(QString,QIcon)), this, SLOT(setTabCaption(QString,QIcon)));
             connect(part, SIGNAL(worksheetSave(QUrl)), this, SLOT(onWorksheetSave(QUrl)));
-            connect(part, SIGNAL(requestOpenWorksheet(QUrl)), this, SLOT(load(QUrl)));
+            connect(part, SIGNAL(showHelp(QString)), this, SIGNAL(showHelp(QString)));
+            connect(part, SIGNAL(hierarchyChanged(QStringList, QStringList, QList<int>)), this, SIGNAL(hierarchyChanged(QStringList, QStringList, QList<int>)));
+            connect(part, SIGNAL(hierarhyEntryNameChange(QString, QString, int)), this, SIGNAL(hierarhyEntryNameChange(QString, QString, int)));
+            connect(this, SIGNAL(requestScrollToHierarchyEntry(QString)), part, SIGNAL(requestScrollToHierarchyEntry(QString)));
+            connect(this, SIGNAL(settingsChanges()), part, SIGNAL(settingsChanges()));
+
             m_parts.append(part);
             if (backend) // If backend empty (loading worksheet from file), then we connect to signal and wait
                 m_parts2Backends[part] = backend->id();
             else
             {
                 m_parts2Backends[part] = QString();
-                connect(part, SIGNAL(setBackendName(QString)), this, SLOT(updateBackendForPart(setBackendName)));
+                connect(part, SIGNAL(setBackendName(QString)), this, SLOT(updateBackendForPart(QString)));
             }
             int tab = m_tabWidget->addTab(part->widget(), i18n("Session %1", sessionCount++));
             m_tabWidget->setCurrentIndex(tab);
@@ -381,30 +409,34 @@ void CantorShell::addWorksheet(const QString& backendName)
 
 void CantorShell::activateWorksheet(int index)
 {
-    QObject* pluginHandler=m_part->findChild<QObject*>(QLatin1String("PanelPluginHandler"));
-    if (pluginHandler)
-        disconnect(pluginHandler,SIGNAL(pluginsChanged()), this, SLOT(updatePanel()));
-
-    // Save part state before change worksheet
+    // Save part panels states before change worksheet
     if (m_part)
     {
         QStringList visiblePanelNames;
-        foreach (QDockWidget* doc, m_panels)
+        for (auto* doc : m_panels)
         {
             if (doc->widget() && doc->widget()->isVisible())
                 visiblePanelNames << doc->objectName();
         }
         m_pluginsVisibility[m_part] = visiblePanelNames;
+
+        auto* wa = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
+        assert(wa);
+        Cantor::PanelPluginHandler::PanelStates states;
+        auto plugins = m_panelHandler.plugins(wa->session());
+        for(auto* plugin : plugins)
+        {
+            states.insert(plugin->name(), plugin->saveState());
+        }
+        m_pluginsStates[m_part] = states;
     }
 
-    m_part=findPart(m_tabWidget->widget(index));
+    m_part = findPart(m_tabWidget->widget(index));
     if(m_part)
     {
         createGUI(m_part);
 
         updateWindowTitle(m_part->url().fileName());
-        QObject* pluginHandler=m_part->findChild<QObject*>(QLatin1String("PanelPluginHandler"));
-        connect(pluginHandler, SIGNAL(pluginsChanged()), this, SLOT(updatePanel()));
         updatePanel();
     }
     else
@@ -415,7 +447,7 @@ void CantorShell::activateWorksheet(int index)
 
 void CantorShell::setTabCaption(const QString& caption, const QIcon& icon)
 {
-    KParts::ReadWritePart* part=dynamic_cast<KParts::ReadWritePart*>(sender());
+    auto* part = dynamic_cast<KParts::ReadWritePart*>(sender());
     if (part)
     {
         if (!caption.isEmpty())
@@ -437,7 +469,7 @@ void CantorShell::closeTab(int index)
         QWidget* widget = m_tabWidget->widget(index);
         if (widget)
         {
-            KParts::ReadWritePart* part= findPart(widget);
+            auto* part = findPart(widget);
             if (part && !reallyCloseThisPart(part))
                 return;
         }
@@ -467,12 +499,13 @@ void CantorShell::closeTab(int index)
 
     m_tabWidget->removeTab(index);
 
-    if(widget->objectName()==QLatin1String("ErrorMessage"))
+    bool isCurrectPartClosed = m_part ? widget == m_part->widget() : false;
+    if(widget->objectName() == QLatin1String("ErrorMessage"))
     {
         widget->deleteLater();
     }else
     {
-        KParts::ReadWritePart* part= findPart(widget);
+        auto* part = findPart(widget);
         if(part)
         {
             saveDockPanelsState(part);
@@ -480,19 +513,22 @@ void CantorShell::closeTab(int index)
             m_parts.removeAll(part);
             m_pluginsVisibility.remove(part);
             m_parts2Backends.remove(part);
+            m_pluginsStates.remove(part);
             delete part;
         }
     }
 
     if (m_tabWidget->count() == 0)
         setCaption(QString());
-    updatePanel();
+
+    if (isCurrectPartClosed || m_part == nullptr)
+        updatePanel();
 }
 
 bool CantorShell::reallyClose(bool checkAllParts) {
     if(checkAllParts && m_parts.count() > 1) {
         bool modified = false;
-        foreach( KParts::ReadWritePart* const part, m_parts)
+        for (auto* part : m_parts)
         {
             if(part->isModified()) {
                 modified = true;
@@ -540,10 +576,10 @@ bool CantorShell::reallyCloseThisPart(KParts::ReadWritePart* part)
 
 
 void CantorShell::closeEvent(QCloseEvent* event) {
-    if(!reallyClose()) {
+    if (!reallyClose()) {
         event->ignore();
     } else {
-        for (KParts::ReadWritePart* part : m_parts)
+        for (auto* part : m_parts)
             saveDockPanelsState(part);
 
         KParts::MainWindow::closeEvent(event);
@@ -553,26 +589,34 @@ void CantorShell::closeEvent(QCloseEvent* event) {
 void CantorShell::showSettings()
 {
     KConfigDialog *dialog = new KConfigDialog(this,  QLatin1String("settings"), Settings::self());
+
     QWidget *generalSettings = new QWidget;
     Ui::SettingsBase base;
     base.setupUi(generalSettings);
+
+    QWidget *formattingSettings = new QWidget;
+    Ui::SettingsFormatting formatting;
+    formatting.setupUi(formattingSettings);
+
     base.kcfg_DefaultBackend->addItems(Cantor::Backend::listAvailableBackends());
 
     dialog->addPage(generalSettings, i18n("General"), QLatin1String("preferences-other"));
-    foreach(Cantor::Backend* backend, Cantor::Backend::availableBackends())
+    dialog->addPage(formattingSettings, i18n("Formatting"), QLatin1String("preferences-other"));
+    for (auto* backend : Cantor::Backend::availableBackends())
     {
         if (backend->config()) //It has something to configure, so add it to the dialog
             dialog->addPage(backend->settingsWidget(dialog), backend->config(), backend->name(),  backend->icon());
     }
 
     dialog->show();
+    connect(dialog, &KConfigDialog::settingsChanged, this, &CantorShell::settingsChanges);
 }
 
 void CantorShell::downloadExamples()
 {
     KNS3::DownloadDialog dialog;
     dialog.exec();
-    foreach (const KNS3::Entry& e,  dialog.changedEntries())
+    for (const auto& e :  dialog.changedEntries())
     {
         qDebug() << "Changed Entry: " << e.name();
     }
@@ -581,15 +625,17 @@ void CantorShell::downloadExamples()
 void CantorShell::openExample()
 {
     QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/examples");
-    if (dir.isEmpty()) return;
+    if (dir.isEmpty())
+        return;
+
     QDir().mkpath(dir);
 
-    QStringList files=QDir(dir).entryList(QDir::Files);
-    QPointer<QDialog> dlg=new QDialog(this);
-    QListWidget* list=new QListWidget(dlg);
-    foreach(const QString& file, files)
+    QStringList files = QDir(dir).entryList(QDir::Files);
+    QPointer<QDialog> dlg = new QDialog(this);
+    QListWidget* list = new QListWidget(dlg);
+    for (const QString& file : files)
     {
-        QString name=file;
+        QString name = file;
         name.remove(QRegularExpression(QStringLiteral("-.*\\.hotstuff-access$")));
         list->addItem(name);
     }
@@ -598,20 +644,20 @@ void CantorShell::openExample()
     dlg->setLayout(mainLayout);
     mainLayout->addWidget(list);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     mainLayout->addWidget(buttonBox);
 
     buttonBox->button(QDialogButtonBox::Ok)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
     buttonBox->button(QDialogButtonBox::Cancel)->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
 
-    connect(buttonBox, SIGNAL(accepted()), dlg, SLOT(accept()) );
-    connect(buttonBox, SIGNAL(rejected()), dlg, SLOT(reject()) );
+    connect(buttonBox, &QDialogButtonBox::accepted, dlg, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, dlg, &QDialog::reject);
 
-    if (dlg->exec()==QDialog::Accepted&&list->currentRow()>=0)
+    if (dlg->exec() == QDialog::Accepted&&list->currentRow()>=0)
     {
-        const QString& selectedFile=files[list->currentRow()];
-        QUrl url = QUrl::fromLocalFile(QDir(dir).absoluteFilePath(selectedFile));
+        const QString& selectedFile = files[list->currentRow()];
+        const QUrl& url = QUrl::fromLocalFile(QDir(dir).absoluteFilePath(selectedFile));
 
         qDebug()<<"loading file "<<url;
         load(url);
@@ -622,43 +668,51 @@ void CantorShell::openExample()
 
 KParts::ReadWritePart* CantorShell::findPart(QWidget* widget)
 {
-    foreach( KParts::ReadWritePart* const part, m_parts)
+    for (auto* part : m_parts)
     {
-        if(part->widget()==widget)
+        if (part->widget() == widget)
             return part;
     }
     return nullptr;
 }
 
+void CantorShell::initPanels()
+{
+    m_panelHandler.loadPlugins();
+
+    for (auto* plugin : m_panelHandler.allPlugins())
+    {
+        if (!plugin)
+        {
+            qDebug()<<"invalid panel found, skipping it.";
+            continue;
+        }
+
+        qDebug()<<"adding panel for "<<plugin->name();
+        plugin->setParentWidget(this);
+        plugin->connectToShell(this);
+
+        QDockWidget* docker = new QDockWidget(plugin->name(), this);
+        docker->setObjectName(plugin->name());
+        docker->setWidget(plugin->widget());
+        addDockWidget(Qt::RightDockWidgetArea, docker);
+
+        docker->hide();
+
+        connect(plugin, &Cantor::PanelPlugin::visibilityRequested, this, &CantorShell::pluginVisibilityRequested);
+        connect(plugin, &Cantor::PanelPlugin::requestRunCommand, this, &CantorShell::pluginCommandRunRequested);
+
+        m_panels.append(docker);
+    }
+}
+
 void CantorShell::updatePanel()
 {
     unplugActionList(QLatin1String("view_show_panel_list"));
 
-    //remove all of the previous panels (but do not delete the widgets)
-    foreach(QDockWidget* dock, m_panels)
-    {
-        QWidget* widget=dock->widget();
-        if(widget!=nullptr)
-        {
-            widget->setParent(this);
-            widget->hide();
-        }
-        dock->deleteLater();
-    }
-    m_panels.clear();
-
     QList<QAction*> panelActions;
 
-    Cantor::PanelPluginHandler* handler=m_part->findChild<Cantor::PanelPluginHandler*>(QLatin1String("PanelPluginHandler"));
-    if(!handler)
-    {
-        qDebug()<<"no PanelPluginHandle found for this part";
-        return;
-    }
-
-    QDockWidget* last=nullptr;
     bool isNewWorksheet = !m_pluginsVisibility.contains(m_part);
-
     if (isNewWorksheet)
     {
         KConfigGroup panelStatusGroup(KSharedConfig::openConfig(), QLatin1String("PanelsStatus"));
@@ -670,50 +724,69 @@ void CantorShell::updatePanel()
         }
     }
 
-    QList<Cantor::PanelPlugin*> plugins=handler->plugins();
-    foreach(Cantor::PanelPlugin* plugin, plugins)
+    Cantor::WorksheetAccessInterface* wa = nullptr;
+    if (m_part)
+        wa = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
+
+    // Worksheet interface can be missing on m_part clossing (and m_part on this moment can be nullptr)
+    QList<Cantor::PanelPlugin*> plugins;
+    if (wa)
     {
-        if(plugin==nullptr)
+        QDockWidget* last = nullptr;
+        plugins = m_panelHandler.activePluginsForSession(wa->session(), m_pluginsStates.contains(m_part) ? m_pluginsStates[m_part] : Cantor::PanelPluginHandler::PanelStates());
+        for (auto* plugin : plugins)
         {
-            qDebug()<<"somethings wrong";
-            continue;
-        }
+            QDockWidget* foundDocker = nullptr;
+            for (auto* docker : m_panels)
+                if (docker->objectName() == plugin->name())
+                {
+                    foundDocker = docker;
+                    break;
+                }
 
-        qDebug()<<"adding panel for "<<plugin->name();
-        plugin->setParentWidget(this);
+            if (!foundDocker)
+            {
+                qDebug() << "something wrong: can't find panel for plugin \"" << plugin->name() << "\"";
+                continue;
+            }
 
-        QDockWidget* docker=new QDockWidget(plugin->name(), this);
-        docker->setObjectName(plugin->name());
-        docker->setWidget(plugin->widget());
-        addDockWidget ( Qt::RightDockWidgetArea,  docker );
-
-        // Set visibility for dock from saved info
-        if (isNewWorksheet)
-        {
-            if (plugin->showOnStartup())
-                docker->show();
+            // Set visibility for dock from saved info
+            if (isNewWorksheet)
+            {
+                if (plugin->showOnStartup())
+                    foundDocker->show();
+                else
+                    foundDocker->hide();
+            }
             else
-                docker->hide();
-        }
-        else
-        {
-            if (m_pluginsVisibility[m_part].contains(plugin->name()))
-                docker->show();
-            else
-                docker->hide();
+            {
+                if (m_pluginsVisibility[m_part].contains(plugin->name()))
+                    foundDocker->show();
+                else
+                    foundDocker->hide();
+            }
+
+            if(last!=nullptr)
+                tabifyDockWidget(last, foundDocker);
+            last = foundDocker;
+
+            //Create the action to show/hide this panel
+            panelActions<<foundDocker->toggleViewAction();
+
         }
+    }
 
-        if(last!=nullptr)
-            tabifyDockWidget(last, docker);
-        last=docker;
-
-        connect(plugin, &Cantor::PanelPlugin::visibilityRequested, this, &CantorShell::pluginVisibilityRequested);
-
-        m_panels.append(docker);
-
-        //Create the action to show/hide this panel
-        panelActions<<docker->toggleViewAction();
-
+    // Hide plugins, which don't supported on current session
+    QList<Cantor::PanelPlugin*> allPlugins=m_panelHandler.allPlugins();
+    for(auto* plugin : allPlugins)
+    {
+        if (plugins.indexOf(plugin) == -1)
+            for (QDockWidget* docker : m_panels)
+                if (docker->objectName() == plugin->name())
+                {
+                    docker->hide();
+                    break;
+                }
     }
 
     plugActionList(QLatin1String("view_show_panel_list"), panelActions);
@@ -727,11 +800,11 @@ void CantorShell::updateNewSubmenu()
     qDeleteAll(m_newBackendActions);
     m_newBackendActions.clear();
 
-    foreach (Cantor::Backend* backend, Cantor::Backend::availableBackends())
+    for (auto* backend : Cantor::Backend::availableBackends())
     {
         if (!backend->isEnabled())
             continue;
-        QAction * action = new QAction(QIcon::fromTheme(backend->icon()), backend->name(), nullptr);
+        QAction* action = new QAction(QIcon::fromTheme(backend->icon()), backend->name(), nullptr);
         action->setData(backend->name());
         connect(action, SIGNAL(triggered()), this, SLOT(fileNew()));
         m_newBackendActions << action;
@@ -741,8 +814,7 @@ void CantorShell::updateNewSubmenu()
 
 Cantor::WorksheetAccessInterface* CantorShell::currentWorksheetAccessInterface()
 {
-    Cantor::WorksheetAccessInterface* wa=m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
-
+    auto* wa = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
     if (!wa)
         qDebug()<<"failed to access worksheet access interface for current part";
 
@@ -751,10 +823,10 @@ Cantor::WorksheetAccessInterface* CantorShell::currentWorksheetAccessInterface()
 
 void CantorShell::pluginVisibilityRequested()
 {
-    Cantor::PanelPlugin* plugin = static_cast<Cantor::PanelPlugin*>(sender());
-    for (QDockWidget* docker: m_panels)
+    auto* plugin = static_cast<Cantor::PanelPlugin*>(sender());
+    for (auto* docker : m_panels)
     {
-        if (plugin->name() == docker->windowTitle())
+        if (plugin->name() == docker->objectName())
         {
             if (docker->isHidden())
                 docker->show();
@@ -779,7 +851,7 @@ void CantorShell::saveDockPanelsState(KParts::ReadWritePart* part)
         QStringList visiblePanelNames;
         if (part == m_part)
         {
-            foreach (QDockWidget* doc, m_panels)
+            for (auto* doc : m_panels)
             {
                 if (doc->widget() && doc->widget()->isVisible())
                     visiblePanelNames << doc->objectName();
@@ -795,7 +867,26 @@ void CantorShell::saveDockPanelsState(KParts::ReadWritePart* part)
 
 void CantorShell::updateBackendForPart(const QString& backend)
 {
-    KParts::ReadWritePart* part=dynamic_cast<KParts::ReadWritePart*>(sender());
+    auto* part = dynamic_cast<KParts::ReadWritePart*>(sender());
     if (part && m_parts2Backends.contains(part) && m_parts2Backends[part].isEmpty())
+    {
         m_parts2Backends[part] = backend;
+
+        KConfigGroup panelStatusGroup(KSharedConfig::openConfig(), QLatin1String("PanelsStatus"));
+        if (m_part == part && panelStatusGroup.hasKey(backend))
+        {
+            const QStringList& plugins = panelStatusGroup.readEntry(m_parts2Backends[m_part]).split(QLatin1Char('\n'));
+            m_pluginsVisibility[m_part] = plugins;
+
+            updatePanel();
+        }
+    }
+}
+
+void CantorShell::pluginCommandRunRequested(const QString& cmd)
+{
+    if (m_part)
+    {
+        QMetaObject::invokeMethod(m_part, "runCommand", Qt::QueuedConnection, Q_ARG(QString, cmd));
+    }
 }
