@@ -28,6 +28,9 @@
 #include <QStringList>
 #include <QMap>
 
+#include "lib/panelpluginhandler.h"
+#include "lib/panelplugin.h"
+
 class QTabWidget;
 class KTextEdit;
 class KRecentFilesAction;
@@ -75,6 +78,13 @@ protected:
      */
     void readProperties(const KConfigGroup &) override;
 
+Q_SIGNALS:
+    void showHelp(QString);
+    void hierarchyChanged(QStringList, QStringList, QList<int>);
+    void hierarhyEntryNameChange(QString, QString, int);
+    void requestScrollToHierarchyEntry(QString);
+    void settingsChanges();
+
 public Q_SLOTS:
     void addWorksheet(const QString& backendName);
     /// Use this method/slot to load whatever file/URL you have
@@ -97,10 +107,12 @@ private Q_SLOTS:
     void downloadExamples();
     void openExample();
 
+    void initPanels();
     void updatePanel();
     void updateNewSubmenu();
 
     void pluginVisibilityRequested();
+    void pluginCommandRunRequested(const QString& cmd);
 
 private:
     void setupActions();
@@ -113,6 +125,7 @@ private:
 
 private:
     QMap<KParts::ReadWritePart*, QStringList> m_pluginsVisibility;
+    QMap<KParts::ReadWritePart*, Cantor::PanelPluginHandler::PanelStates> m_pluginsStates;
     QList<KParts::ReadWritePart *> m_parts;
     QMap<KParts::ReadWritePart*, QString> m_parts2Backends;
     KParts::ReadWritePart* m_part;
@@ -122,6 +135,8 @@ private:
     QDockWidget* m_helpDocker;
     KRecentFilesAction* m_recentProjectsAction;
 
+    Cantor::PanelPluginHandler m_panelHandler;
+
     // For better UX: set previous used filter in "Open" action as default filter
     QString m_previousFilter;
 };
