@@ -25,7 +25,7 @@
 #include <QVector>
 
 #include <KParts/ReadWritePart>
-#include <lib/session.h>
+#include "lib/session.h"
 
 class QWidget;
 class Worksheet;
@@ -83,9 +83,12 @@ public:
 Q_SIGNALS:
     void setCaption(const QString& caption, const QIcon& icon);
     void showHelp(const QString& help);
+    void hierarchyChanged(QStringList, QStringList, QList<int>);
+    void hierarhyEntryNameChange(QString name, QString searchName, int depth);
     void worksheetSave(const QUrl& url);
-    void requestOpenWorksheet(const QUrl& url);
     void setBackendName(const QString& name);
+    void requestScrollToHierarchyEntry(QString);
+    void settingsChanges();
 
 public Q_SLOTS:
     void updateCaption();
@@ -132,7 +135,6 @@ protected Q_SLOTS:
     void worksheetSessionLoginDone();
     void initialized();
 
-    void pluginsChanged();
     void runCommand(const QString& value);
 
     void runAssistant();
@@ -168,7 +170,6 @@ private:
     WorksheetView *m_worksheetview;
     SearchBar *m_searchBar;
     QPointer<ScriptEditorWidget> m_scriptEditor;
-    Cantor::PanelPluginHandler* m_panelHandler;
 
     QProgressDialog* m_initProgressDlg;
     bool m_showProgressDlg;
