@@ -55,7 +55,7 @@ class ImageEntry : public WorksheetEntry
 
     void interruptEvaluation() override;
 
-    void layOutForWidth(qreal w, bool force = false) override;
+    void layOutForWidth(qreal entry_zone_x, qreal w, bool force = false) override;
 
   public Q_SLOTS:
     bool evaluate(WorksheetEntry::EvaluationOption evalOp = FocusNext) override;
@@ -76,6 +76,7 @@ class ImageEntry : public WorksheetEntry
 
   private:
     QString m_imagePath;
+    QString m_fileName;
     ImageSize m_displaySize;
     ImageSize m_printSize;
     bool m_useDisplaySizeForPrinting;
