@@ -23,6 +23,8 @@
 #include "lib/imageresult.h"
 #include "lib/epsresult.h"
 
+#include <config-cantor.h>
+
 #include <KLocalizedString>
 #include <QFileDialog>
 #include <QDebug>
@@ -54,10 +56,27 @@ void ImageResultItem::update()
     Q_ASSERT(m_result->type() == Cantor::ImageResult::Type || m_result->type() == Cantor::EpsResult::Type);
     switch(m_result->type()) {
     case Cantor::ImageResult::Type:
-        setImage(m_result->data().value<QImage>());
+    {
+        QSize displaySize = static_cast<Cantor::ImageResult*>(m_result)->displaySize();
+        if (displaySize.isValid())
+            setImage(m_result->data().value<QImage>(), displaySize);
+        else
+            setImage(m_result->data().value<QImage>());
+    }
         break;
     case Cantor::EpsResult::Type:
-        setEps(m_result->data().toUrl());
+    {
+        Cantor::EpsResult* epsResult = static_cast<Cantor::EpsResult*>(m_result);
+#ifdef WITH_EPS
+        bool cacheVersionEnough = worksheet()->renderer()->scale() == 1.0 && !worksheet()->isPrinting();
+        if (!epsResult->image().isNull() && cacheVersionEnough)
+            setImage(epsResult->image());
+        else
+            setEps(m_result->data().toUrl());
+#else
+        setImage(epsResult->image());
+#endif
+    }
         break;
     default:
         break;
@@ -91,8 +110,3 @@ void ImageResultItem::deleteLater()
 {
     WorksheetImageItem::deleteLater();
 }
-
-EpsRenderer* ImageResultItem::epsRenderer()
-{
-    return qobject_cast<Worksheet*>(scene())->epsRenderer();
-}
