@@ -18,12 +18,16 @@
     Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
  */
 
+#include <vector>
+
 #include "backend.h"
 #include "extension.h"
 
 #include <QDir>
 #include <QRegularExpression>
 #include <QUrl>
+#include <QProcess>
+#include <QStandardPaths>
 
 #include <KPluginMetaData>
 #include <KLocalizedString>
@@ -38,6 +42,7 @@ class Cantor::BackendPrivate
     QString icon;
     QString url;
     bool enabled{true};
+    QList<GraphicPackage> supportedGraphicPackagesCache;
 };
 
 Backend::Backend(QObject* parent, const QList<QVariant>& args) : QObject(parent),
@@ -135,6 +140,12 @@ QList<Backend*> Backend::availableBackends()
             KPluginFactory* factory = KPluginLoader(loader.fileName()).factory();
             Backend* backend = factory->create<Backend>(QCoreApplication::instance());
 
+            if (!backend){
+                qDebug() << "Error using plugin " << loader.fileName();
+                qDebug() << "Error message: " << loader.errorString();
+                continue;
+            }
+
             KPluginMetaData info(loader);
             backend->d->name=info.name();
             backend->d->comment=info.description();
@@ -204,3 +215,62 @@ bool Backend::checkExecutable(const QString& name, const QString& path, QString*
 
     return true;
 }
+
+bool Cantor::Backend::testProgramWritable(const QString& program, const QStringList& args, const QString& filename, const QString& expectedContent, QString* reason, int timeOut)
+{
+    QProcess process;
+    process.setProgram(program);
+    process.setArguments(args);
+    process.start();
+
+    if (process.waitForFinished(timeOut) == false)
+    {
+        if (reason)
+            *reason = i18n("The program %1 didn't finish the execution after %2 milliseconds during the plot integration test.", QFileInfo(program).fileName(), timeOut);
+
+        return false;
+    }
+
+    QFile file(filename);
+    if (!file.open(QIODevice::ReadOnly))
+    {
+        if (reason)
+            *reason = i18n("Failed to open the file %1 during the plot integration test.", filename);
+        return false;
+    }
+
+    QString fileContent = QString::fromLocal8Bit(file.readAll());
+    if (fileContent.trimmed() != expectedContent)
+    {
+        if (reason)
+            *reason = i18n("Failed to parse the result during the plot integration test.");
+        return false;
+    }
+
+    file.close();
+    file.remove();
+
+    return true;
+}
+
+QList<GraphicPackage> Backend::availableGraphicPackages() const
+{
+    if (d->supportedGraphicPackagesCache.size() != 0)
+        return d->supportedGraphicPackagesCache;
+
+    if (!(capabilities() & Capability::IntegratedPlots))
+        return QList<GraphicPackage>(); // because this cache is empty
+
+    QString packagesFile = id() + QLatin1String("/graphic_packages.xml");
+    QString filename = QStandardPaths::locate(QStandardPaths::AppDataLocation, packagesFile, QStandardPaths::LocateFile);
+
+    if (filename.isEmpty())
+        filename = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("cantor/") + packagesFile, QStandardPaths::LocateFile);
+
+    if (filename.isEmpty())
+        return QList<GraphicPackage>();
+
+    d->supportedGraphicPackagesCache = GraphicPackage::loadFromFile(filename);
+
+    return d->supportedGraphicPackagesCache;
+}
