@@ -19,12 +19,17 @@
  */
 
 #include "latexresult.h"
-using namespace Cantor;
 
 #include <QFile>
 #include <QTextStream>
+#include <QJsonValue>
+#include <QJsonObject>
 #include <QDebug>
 
+#include "jupyterutils.h"
+
+using namespace Cantor;
+
 class Cantor::LatexResultPrivate
 {
   public:
@@ -38,7 +43,7 @@ class Cantor::LatexResultPrivate
     QString plain;
 };
 
-LatexResult::LatexResult(const QString& code, const QUrl &url, const QString& plain) : EpsResult( url ),
+LatexResult::LatexResult(const QString& code, const QUrl &url, const QString& plain, const QImage& image) : EpsResult( url, image ),
                                                                                        d(new LatexResultPrivate)
 {
     d->code=code;
@@ -117,16 +122,38 @@ QString LatexResult::toLatex()
 QDomElement LatexResult::toXml(QDomDocument& doc)
 {
     qDebug()<<"saving textresult "<<toHtml();
-    QDomElement e=doc.createElement(QStringLiteral("Result"));
+    QDomElement e = EpsResult::toXml(doc);
     e.setAttribute(QStringLiteral("type"), QStringLiteral("latex"));
-    QUrl url= EpsResult::data().toUrl();
-    e.setAttribute(QStringLiteral("filename"), url.fileName());
     QDomText txt=doc.createTextNode(code());
     e.appendChild(txt);
 
     return e;
 }
 
+QJsonValue Cantor::LatexResult::toJupyterJson()
+{
+    QJsonObject root;
+
+    if (executionIndex() != -1)
+    {
+        root.insert(QLatin1String("output_type"), QLatin1String("execute_result"));
+        root.insert(QLatin1String("execution_count"), executionIndex());
+    }
+    else
+        root.insert(QLatin1String("output_type"), QLatin1String("display_data"));
+
+    QJsonObject data;
+    data.insert(QLatin1String("text/plain"), JupyterUtils::toJupyterMultiline(d->plain));
+    data.insert(QLatin1String("text/latex"), JupyterUtils::toJupyterMultiline(d->code));
+    if (!image().isNull())
+        data.insert(JupyterUtils::pngMime, JupyterUtils::packMimeBundle(image(), JupyterUtils::pngMime));
+    root.insert(QLatin1String("data"), data);
+
+    root.insert(QLatin1String("metadata"), jupyterMetadata());
+
+    return root;
+}
+
 void LatexResult::save(const QString& filename)
 {
     if(isCodeShown())
