@@ -28,6 +28,7 @@ class Session;
 }
 
 class QTreeView;
+class QToolButton;
 class QAbstractItemModel;
 
 class VariableManagerWidget : public QWidget
@@ -53,6 +54,10 @@ class VariableManagerWidget : public QWidget
     Cantor::Session* m_session;
     QAbstractItemModel* m_model;
     QTreeView* m_table;
+    QToolButton* m_newBtn;
+    QToolButton* m_loadBtn;
+    QToolButton* m_saveBtn;
+    QToolButton* m_clearBtn;
 };
 
 #endif /* _VARIABLEMANAGERWIDGET_H */
