@@ -31,6 +31,8 @@
 #include "lib/imageresult.h"
 #include "lib/epsresult.h"
 #include "lib/animationresult.h"
+#include "lib/mimeresult.h"
+#include "lib/htmlresult.h"
 
 #include <QObject>
 
@@ -48,6 +50,8 @@ ResultItem* ResultItem::create(WorksheetEntry* parent, Cantor::Result* result)
     switch(result->type()) {
     case Cantor::TextResult::Type:
     case Cantor::LatexResult::Type:
+    case Cantor::MimeResult::Type:
+    case Cantor::HtmlResult::Type:
         {
             return new TextResultItem(parent, result);
         }
