@@ -57,7 +57,9 @@ class WorksheetImageItem : public QGraphicsObject
 
     void setEps(const QUrl &url);
     void setImage(QImage img);
+    void setImage(QImage img, QSize displaySize);
     void setPixmap(QPixmap pixmap);
+    QPixmap pixmap() const;
 
     virtual void populateMenu(QMenu* menu, QPointF pos);
     Worksheet* worksheet();
@@ -72,7 +74,6 @@ class WorksheetImageItem : public QGraphicsObject
   private:
     QPixmap m_pixmap;
     QSizeF m_size;
-    qreal m_maxWidth;
 };
 
 #endif //WORKSHEETIMAGEITEM_H
