@@ -23,7 +23,6 @@
 #include "worksheetentry.h"
 #include "lib/renderer.h"
 #include "worksheetcursor.h"
-#include "extended_document.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -46,7 +45,6 @@
 WorksheetTextItem::WorksheetTextItem(QGraphicsObject* parent, Qt::TextInteractionFlags ti)
     : QGraphicsTextItem(parent)
 {
-    setDocument(new ExtendedDocument(this));
     setTextInteractionFlags(ti);
     if (ti & Qt::TextEditable) {
         setCursor(Qt::IBeamCursor);
@@ -598,18 +596,26 @@ void WorksheetTextItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
     QTextCursor cursor = textCursor();
     const QChar repl = QChar::ObjectReplacementCharacter;
 
-    if (!cursor.hasSelection()) {
-        // We look at the current cursor and the next cursor for a
-        // ObjectReplacementCharacter
-        for (int i = 2; i; --i) {
-            if (document()->characterAt(cursor.position()-1) == repl) {
-                setTextCursor(cursor);
-                emit doubleClick();
-                return;
+    if (m_eventBehaviour == DoubleClickEventBehaviour::ImageReplacement)
+    {
+        if (!cursor.hasSelection()) {
+            // We look at the current cursor and the next cursor for a
+            // ObjectReplacementCharacter
+            for (int i = 2; i; --i) {
+                if (document()->characterAt(cursor.position()-1) == repl) {
+                    setTextCursor(cursor);
+                    emit doubleClick();
+                    return;
+                }
+                cursor.movePosition(QTextCursor::NextCharacter);
             }
-            cursor.movePosition(QTextCursor::NextCharacter);
+        } else if (cursor.selectedText().contains(repl)) {
+            emit doubleClick();
+            return;
         }
-    } else if (cursor.selectedText().contains(repl)) {
+    }
+    else if (m_eventBehaviour == DoubleClickEventBehaviour::Simple)
+    {
         emit doubleClick();
         return;
     }
@@ -923,3 +929,13 @@ void WorksheetTextItem::denyEditing()
 {
     setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByKeyboard);
 }
+
+WorksheetTextItem::DoubleClickEventBehaviour WorksheetTextItem::doubleClickBehaviour()
+{
+    return m_eventBehaviour;
+}
+
+void WorksheetTextItem::setDoubleClickBehaviour(WorksheetTextItem::DoubleClickEventBehaviour behaviour)
+{
+    m_eventBehaviour = behaviour;
+}
